# pybricks-stubs

This package is meant to provide typings (and IntelliSense) to those developing Python programs for the LEGO<sup>&reg;</sup> MINDSTORMS<sup>&reg;</sup> EV3 with the official LEGO<sup>&reg;</sup> software ([pybricks](https://education.lego.com/en-us/support/mindstorms-ev3/python-for-ev3)). All typings are based on the [LEGO<sup>&reg;</sup> API](https://le-www-live-s.legocdn.com/sc/media/files/ev3-micropython/ev3micropythonv100-71d3f28c59a1e766e92a59ff8500818e.pdf).

This package does not support executing robot code on the computer or on the robot. This package does provide type hinting while writing Python code on the computer for later upload/deployment to the robot. 

This package is **not** produced or maintained by LEGO<sup>&reg;</sup>, nor is it officially endorsed by LEGO<sup>&reg;</sup> or *FIRST*<sup>&reg;</sup>.

Please report any issues you encounter.
